// FilePropertyDlg.h
// (c) 2003-2005 exeal

#ifndef _FILE_PROPERTY_DLG_H_
#define _FILE_PROPERTY_DLG_H_
#include "resource.h"
#include "../Manah/Dialog.h"


namespace Alpha {
	class CAlphaDoc;

	///	[t@C]-[vpeB] _CAO
	class CFilePropertyDlg : public Manah::Windows::Controls::CFixedIdDialog<IDD_DLG_FILEPROPERTY> {
		// RXgN^
	public:
		explicit CFilePropertyDlg(const CAlphaDoc& buffer);

		// bZ[Wnh
	protected:
		virtual bool	OnInitDialog(HWND hwndFocus, LPARAM lInitParam);	// WM_INITDIALOG
		virtual void	OnSize(UINT nType, int cx, int cy);					// WM_SIZE

		// f[^o
	private:
		const CAlphaDoc&	m_buffer;
	};
}

#endif /* _FILE_OPERATION_DLG_H_ */

/* [EOF] */